@@ -16,34 +16,32 @@ columns.
 """
 import json
 from pathlib import Path
-from typing import Iterator, Union
+from typing import Union
 
 import pandas as pd
 
-from .pretalx.types import Submission
+from .pretalx.utils import Col as PretalxCol
 
 
-class Col:
-    """Convention of column names for the functions below."""
+class Col(PretalxCol):
+    """Additional conventions used for reviews"""
 
-    timestamp = "Timestamp"
-    name = "Name"
     address_as = "Address as"
-    affiliation = "Affiliation"
-    email = "Email"
-    curr_assignments = "Current Assignments"
-    num_assignments = "#Assignments"
-    track = "Track"
-    submission = "Submission"
-    needed_nreviews = "Needed #Reviews"
     track_prefs = "Track Preferences"
-    pretalx_activated = "Pretalx activated"
     committee_contact = "Committee Contact"
-    availability = "Availability"
-    availability_comment = "Availability Comment"
     all_proposals = "All Proposals"
-    public = "Public"
-    comment = "Comment"
+
+    pretalx_activated = "Pretalx activated"
+
+    curr_assignments = "Current Assignments"
+    nassignments = "#Assignments"
+
+    target_nreviews = "Target #Reviews"
+    rem_nreviews = "Remaining #Reviews"
+    done_nreviews = "Done #Reviews"
+
+    nvotes = "#Votes"
+    vote_score = "Vote Score"
 
 
 def read_assignment_as_df(file_path: Path) -> pd.DataFrame:
@@ -55,15 +53,6 @@ def read_assignment_as_df(file_path: Path) -> pd.DataFrame:
     return df
 
 
-def sub_tracks_as_df(all_subs: Iterator[Submission]) -> pd.DataFrame:
-    """Retrieves all submissions and creates a dataframe of submission codes and tracks"""
-    return (
-        pd.DataFrame({s.code: [s.track.en if s.track else "None"] for s in all_subs})
-        .T.rename(columns={0: Col.track})
-        .rename_axis(index=Col.submission)
-    )
-
-
 def save_assignments_as_json(df: pd.DataFrame, file_path: Union[Path, str]):
     """Save the dataframe as proposal assignment JSON file"""
     file_path = Path(file_path)
